import { useLocalePath } from "#i18n";
import { defineComponent, computed, defineNuxtLink, h } from "#imports";
import { hasProtocol } from "ufo";
const NuxtLinkLocale = defineNuxtLink({ componentName: "NuxtLinkLocale" });
export default defineComponent({
  name: "NuxtLinkLocale",
  props: {
    ...NuxtLinkLocale.props,
    to: {
      type: [String, Object],
      default: void 0,
      required: false
    },
    locale: {
      type: String,
      default: void 0,
      required: false
    }
  },
  setup(props, { slots }) {
    const localePath = useLocalePath();
    const resolvedPath = computed(() => props.to != null ? localePath(props.to, props.locale) : props.to);
    const isExternal = computed(() => {
      if (props.external) {
        return true;
      }
      if (props.target && props.target !== "_self") {
        return true;
      }
      if (typeof props.to === "object") {
        return false;
      }
      return props.to === "" || hasProtocol(props.to, { acceptRelative: true });
    });
    return () => isExternal.value ? h(NuxtLinkLocale, props, slots.default) : h(NuxtLinkLocale, { ...props, to: resolvedPath }, slots.default);
  }
});
